script.aculo.us Effects functional test file

# script.aculo.us fade/appear effect functional test

Note: these tests use the browser default CSS style rules.

## DIV

TEST
MochiKit.Visual.fade | MochiKit.Visual.appear

## SPAN

TEST
MochiKit.Visual.fade | MochiKit.Visual.appear

## P

TEST

MochiKit.Visual.fade | MochiKit.Visual.appear

## IMG

MochiKit.Visual.fade | MochiKit.Visual.appear

The following elements are not supported with fade/appear on all browsers!

## TABLE

TEST

MochiKit.Visual.fade | MochiKit.Visual.appear

## TBODY

TEST

MochiKit.Visual.fade | MochiKit.Visual.appear

## TR

TEST

MochiKit.Visual.fade | MochiKit.Visual.appear

## TD

TEST

MochiKit.Visual.fade | MochiKit.Visual.appear